<?php
// $Id: default.profile,v 1.22 2007/12/17 12:43:34 goba Exp $

/**
 * Return an array of the modules to be enabled when this profile is installed.
 *
 * @return
 *   An array of modules to enable.
 */
function default_profile_modules() {
  $core_modules = array('color', 'comment', 'help', 'menu', 'taxonomy', 'dblog', 'blog', 'contact', 'forum', 'path', 'poll', 'profile',
    'search', 'statistics', 'tracker', 'update', 'upload');

  //added modules by bk
  $contributed_modules = array('calendar', 'content', 'content_copy', 'fieldgroup', 'nodereference', 'number', 'optionwidgets',
  'text', 'token', 'userreference', 'content_permissions', 'wysiwyg','views', 'views_ui', 'views_export', 'date', 'date_api', 
  'date_timezone', 'date_popup', 'pathauto', 'openvce_install');

  return array_merge($core_modules, $contributed_modules);
}

/**
 * Return a description of the profile for the initial installation screen.
 *
 * @return
 *   An array with keys 'name' and 'description' describing this profile,
 *   and optional 'language' to override the language selection for
 *   language-specific profiles.
 */
function default_profile_details() {  
  return array(
    'name' => 'Open Virtual Collaboration Environment',
    'description' => 'This is the customized OpenVCE Drupal Distribution.'
  );
}

/**
 * Return a list of tasks that this profile supports.
 *
 * @return
 *   A keyed array of tasks the profile will perform during
 *   the final stage. The keys of the array will be used internally,
 *   while the values will be displayed to the user in the installer
 *   task list.
 */
function default_profile_task_list() {
}

/**
 * Perform any final installation tasks for this profile.
 *
 * The installer goes through the profile-select -> locale-select
 * -> requirements -> database -> profile-install-batch
 * -> locale-initial-batch -> configure -> locale-remaining-batch
 * -> finished -> done tasks, in this order, if you don't implement
 * this function in your profile.
 *
 * If this function is implemented, you can have any number of
 * custom tasks to perform after 'configure', implementing a state
 * machine here to walk the user through those tasks. First time,
 * this function gets called with $task set to 'profile', and you
 * can advance to further tasks by setting $task to your tasks'
 * identifiers, used as array keys in the hook_profile_task_list()
 * above. You must avoid the reserved tasks listed in
 * install_reserved_tasks(). If you implement your custom tasks,
 * this function will get called in every HTTP request (for form
 * processing, printing your information screens and so on) until
 * you advance to the 'profile-finished' task, with which you
 * hand control back to the installer. Each custom page you
 * return needs to provide a way to continue, such as a form
 * submission or a link. You should also set custom page titles.
 *
 * You should define the list of custom tasks you implement by
 * returning an array of them in hook_profile_task_list(), as these
 * show up in the list of tasks on the installer user interface.
 *
 * Remember that the user will be able to reload the pages multiple
 * times, so you might want to use variable_set() and variable_get()
 * to remember your data and control further processing, if $task
 * is insufficient. Should a profile want to display a form here,
 * it can; the form should set '#redirect' to FALSE, and rely on
 * an action in the submit handler, such as variable_set(), to
 * detect submission and proceed to further tasks. See the configuration
 * form handling code in install_tasks() for an example.
 *
 * Important: Any temporary variables should be removed using
 * variable_del() before advancing to the 'profile-finished' phase.
 *
 * @param $task
 *   The current $task of the install system. When hook_profile_tasks()
 *   is first called, this is 'profile'.
 * @param $url
 *   Complete URL to be used for a link or form action on a custom page,
 *   if providing any, to allow the user to proceed with the installation.
 *
 * @return
 *   An optional HTML string to display to the user. Only used if you
 *   modify the $task, otherwise discarded.
 */
function default_profile_tasks(&$task, $url) {
  _newprofile_modify_settings();  
  _newprofile_set_content_type();
  _newprofile_profile_set_cck_fields();
  _newprofile_modify_menus();
  _newprofile_profile_set_permissions();
  _newprofile_profile_save_nodes();
  _newprofile_profile_config_wysiwyg();
  _newprofile_profile_config_blocks();
  _newprofile_profile_set_term();
  //_newprofile_profile_set_views();
}

function _newprofile_set_content_type() {
  //var_export(content_fields('field_translator_note', 'feature'));

  // Insert default user-defined node types into the database. For a complete
  // list of available node type attributes, refer to the node type API
  // documentation at: http://api.drupal.org/api/HEAD/function/hook_node_info.
  $types = array();
  $types = array(
    array(
      'type' => 'page',
      'name' => st('Page'),
      'module' => 'node',
      'description' => st("A <em>page</em>, similar in form to a <em>story</em>, is a simple method for creating and displaying information that rarely changes, such as an \"About us\" section of a website. By default, a <em>page</em> entry does not allow visitor comments and is not featured on the site's initial home page."),
      'custom' => TRUE,
      'modified' => TRUE,
      'locked' => FALSE,
      'help' => '',
      'min_word_count' => '',
    ),
    array(
      'type' => 'story',
      'name' => st('Story'),
      'module' => 'node',
      'description' => st("A <em>story</em>, similar in form to a <em>page</em>, is ideal for creating and displaying content that informs or engages website visitors. Press releases, site announcements, and informal blog-like entries may all be created with a <em>story</em> entry. By default, a <em>story</em> entry is automatically featured on the site's initial home page, and provides the ability to post comments."),
      'custom' => TRUE,
      'modified' => TRUE,
      'locked' => FALSE,
      'help' => '',
      'min_word_count' => '',
    ),

    //added custom event content type by bk 
    array(
      'type' => 'event',
      'name' => st('Event'),
      'module' => 'node',
      'description' => st("An Event with a Date."),
      'custom' => TRUE,
      'modified' => TRUE,
      'locked' => FALSE,
      'help' => '',
      'min_word_count' => '',
    ),

  );

  foreach ($types as $type) {
    $type = (object) _node_type_set_defaults($type);
    node_type_save($type);
  }

  // Default page to not be promoted and have comments disabled.
  variable_set('node_options_page', array('status'));
  variable_set('comment_page', COMMENT_NODE_DISABLED);

  // Don't display date and author information for page nodes by default.
  $theme_settings = variable_get('theme_settings', array());
  $theme_settings['toggle_node_info_page'] = FALSE;
  variable_set('theme_settings', $theme_settings);
}


function _newprofile_modify_menus() {
  $upcoming_event = array(
    'menu_name' => 'navigation',
    'link_title' => st('Upcoming Events'),
    'link_path' => 'upcomingevents',
    'weight' => 2,
  );
  
  menu_link_save($upcoming_event);
  menu_rebuild();   // Also need this to get the FORUMS link in the database
  
  // Enable FORUMs link
  db_query("UPDATE menu_links SET hidden=0, customized=1 WHERE link_path = 'forum'");
  db_query("UPDATE menu_links SET options='%s' WHERE link_path = 'forum'", 'a:1:{s:10:"attributes";a:1:{s:5:"title";s:0:"";}}'); 
  menu_rebuild();
}


/**
 * Implementation of hook_profile_tasks().
 */
function _newprofile_modify_settings() {
  global $theme_key;

  variable_del('user_mail_status_activated_notify');

  // Theme related.
  system_initialize_theme_blocks('openvce');
  variable_set('theme_default', 'openvce');
  variable_set('admin_theme', 'openvce');
  $theme_settings = variable_get('theme_settings', array());
  $theme_settings['toggle_node_info_page'] = FALSE;
  variable_set('theme_settings', $theme_settings);
  // $theme_key = 'openvce';

  // Set logo and favicon.
  $openvce_settings = variable_get('theme_openvce_settings', array());
  $openvce_path = drupal_get_path('theme', 'openvce');
  $logo_path = $openvce_path . '/openvceprofile/openvce-logo-190x72.jpg';
  $openvce_settings['default_logo'] = 0;
  $openvce_settings['logo_path'] = $logo_path;
  $favicon_path = $openvce_path . '/openvceprofile/openvce-favicon.ico';
  $openvce_settings['default_favicon'] = 0;
  $openvce_settings['favicon_path'] = $favicon_path;
  variable_set('theme_openvce_settings', $openvce_settings);
  variable_set('site_footer', 'This website uses the OpenVCE Drupal distribution.  You can find out more at <a href="http://openvce.net">openvce.net</a>. For commercial support options please visit <a href="http://cleverzebra.com/openvce">Clever Zebra</a>.');
}

/**
 * Implementation of hook_form_alter().
 *
 * Allows the profile to alter the site-configuration form. This is
 * called through custom invocation, so $form_state is not populated.
 */
function default_form_alter(&$form, $form_state, $form_id) {
  if ($form_id == 'install_configure') {
    // Set default for site name field.
    $form['site_information']['site_name']['#default_value'] = 'OpenVCE';
  }
}


/************************************************************/
function _newprofile_profile_set_cck_fields() {
    $date_field = array();
    $date_field = array ( 
      'field_name' => 'field_date', 
      'type_name' => 'event', 
      'display_settings' => 
      array ( 'label' => 
      array ( 'format' => 'above', 
      'exclude' => 0, ), 
      'teaser' => 
      array ( 'format' => 'default', 
      'exclude' => 0, ), 
      'full' => 
      array ( 'format' => 'default', 
      'exclude' => 0, ), 4 => 
      array ( 'format' => 'default', 
      'exclude' => 0, ), 2 => 
      array ( 'format' => 'default', 
      'exclude' => 0, ), 3 => 
      array ( 'format' => 'default', 
      'exclude' => 0, ), ), 
      'widget_active' => '1', 
      'type' => 'date', 
      'required' => '0', 
      'multiple' => '0', 
      'db_storage' => '1', 
      'module' => 'date', 
      'active' => '1', 
      'locked' => '0', 
      'columns' => 
      array ( 'value' => 
      array ( 'type' => 'varchar', 
      'length' => 20, 
      'not null' => false, 
      'sortable' => true, 
      'views' => true, ), ), 
      'granularity' => 
      array ( 'year' => 'year', 
      'month' => 'month', 
      'day' => 'day',
      'hour' => 'hour',
      'minute' => 'minute',
      'second' => 'second'), 
      'timezone_db' => '', 
      'tz_handling' => 'none', 
      'todate' => '', 
      'repeat' => 0, 
      'repeat_collapsed' => '', 
      'default_format' => 'medium', 
      'widget' => 
      array ( 'default_value' => 'blank', 
      'default_value_code' => '', 
      'default_value2' => 'same', 
      'default_value_code2' => '', 
      'input_format' => 'm/d/Y - g:ia', 
      'input_format_custom' => '', 
      'increment' => '1', 
      'text_parts' => 
      array ( ), 
      'year_range' => '-3:+3', 
      'label_position' => 'above', 
      'label' => 'Date', 
      'weight' => 0, 
      'description' => '', 
      'type' => 'date_popup', 
      'module' => 'date', ), 
    );
  _newprofile_install_cck($date_field, 'event');  
}

/**
 * Import CCK settings.
 *
 * @param $field
 *   The d  ata provided by var_export(content_fields(fieldname, content_type)).
 * @param $content_type
 *   The content type that this field should be added to.
 */
function _newprofile_install_cck($field, $content_type) {
  module_load_include('inc', 'content', 'includes/content.crud');
  $field['type_name'] = $content_type;
  content_field_instance_create($field);
}

/**
 * Set the roles and permissions that will be used in this profile.
 */

function _newprofile_profile_set_permissions() {
    // Define new roles.
  //db_query("INSERT INTO {role} (rid, name) VALUES(%d, '%s')", 2, 'authenticated user');
  // Update "authenticated user" permissions.
  db_query("UPDATE {permission} SET perm = '%s' WHERE rid = %d", 'access content, search content, use advanced search, create blog entries, delete own blog entries, 
   edit own blog entries, access comments, post comments, access site-wide contact form, create forum topics, 
   delete own forum topics, edit any forum topic, edit own forum topics, create poll content, delete own poll content, 
   edit own poll content, access user profiles, change own username, search content, upload files, view uploaded files, access tinymce', 2);
   
  db_query("UPDATE {permission} SET perm = '%s' WHERE rid = %d", 'access content, search content, use advanced search', 1);

}

/**
 * Save nodes which will be used in the profile.
 */
function _newprofile_profile_save_nodes() {
  // Determine the username of user 1.
  $user_1 = user_load(array('uid' => 1));
  $user_1_name = $user_1->name;

  $control_center_body = "Welcome to OpenVCE!!!!!";
  $control_center = array (
    'type' => 'page',
    'language' => 'en',
    'uid' => 1,
    'status' => 1,
    'comment' => 0,
    'promote' => 1,
    'moderate' => 0,
    'sticky' => 0,
    'tnid' => 0,
    'translate' => 0,
    'vid' => 1,
    'revision_uid' => 1,
    'title' => st('OpenVCE Home Page'),
    'body' => $control_center_body,
    'teaser' => node_teaser($control_center_body),
    'format' => 3,
    'name' => $user_1_name,
  );
  $control_center = (object) $control_center;
  node_save($control_center);

}

function _newprofile_profile_config_wysiwyg() {
    db_query("INSERT into {wysiwyg} VALUES (1, 'tinymce', '%s')",
        'a:21:{s:7:"default";i:1;s:11:"user_choose";i:0;s:11:"show_toggle";i:1;s:5:"theme";s:8:"advanced";s:8:"language";s:2:"en";s:7:"buttons";a:2:{s:7:"default";a:12:{s:4:"bold";i:1;s:6:"italic";i:1;s:9:"underline";i:1;s:11:"justifyleft";i:1;s:13:"justifycenter";i:1;s:12:"justifyright";i:1;s:11:"justifyfull";i:1;s:7:"bullist";i:1;s:7:"numlist";i:1;s:3:"cut";i:1;s:4:"copy";i:1;s:5:"paste";i:1;}s:5:"paste";a:2:{s:9:"pastetext";i:1;s:9:"pasteword";i:1;}}s:11:"toolbar_loc";s:3:"top";s:13:"toolbar_align";s:4:"left";s:8:"path_loc";s:4:"none";s:8:"resizing";i:0;s:11:"verify_html";i:1;s:12:"preformatted";i:0;s:22:"convert_fonts_to_spans";i:1;s:17:"remove_linebreaks";i:1;s:23:"apply_source_formatting";i:0;s:27:"paste_auto_cleanup_on_paste";i:0;s:13:"block_formats";s:32:"p,address,pre,h2,h3,h4,h5,h6,div";s:11:"css_setting";s:5:"theme";s:8:"css_path";s:0:"";s:11:"css_classes";s:0:"";s:13:"form_build_id";s:37:"form-93997d3955821d4d6b6ecb6b8341c1fc";}');
        
     db_query("INSERT into {wysiwyg} VALUES (2, 'tinymce', '%s')",
        'a:21:{s:7:"default";i:1;s:11:"user_choose";i:0;s:11:"show_toggle";i:1;s:5:"theme";s:8:"advanced";s:8:"language";s:2:"en";s:7:"buttons";a:2:{s:7:"default";a:12:{s:4:"bold";i:1;s:6:"italic";i:1;s:9:"underline";i:1;s:11:"justifyleft";i:1;s:13:"justifycenter";i:1;s:12:"justifyright";i:1;s:11:"justifyfull";i:1;s:7:"bullist";i:1;s:7:"numlist";i:1;s:3:"cut";i:1;s:4:"copy";i:1;s:5:"paste";i:1;}s:5:"paste";a:2:{s:9:"pastetext";i:1;s:9:"pasteword";i:1;}}s:11:"toolbar_loc";s:3:"top";s:13:"toolbar_align";s:4:"left";s:8:"path_loc";s:4:"none";s:8:"resizing";i:0;s:11:"verify_html";i:1;s:12:"preformatted";i:0;s:22:"convert_fonts_to_spans";i:1;s:17:"remove_linebreaks";i:1;s:23:"apply_source_formatting";i:0;s:27:"paste_auto_cleanup_on_paste";i:0;s:13:"block_formats";s:32:"p,address,pre,h2,h3,h4,h5,h6,div";s:11:"css_setting";s:5:"theme";s:8:"css_path";s:0:"";s:11:"css_classes";s:0:"";s:13:"form_build_id";s:37:"form-93997d3955821d4d6b6ecb6b8341c1fc";}');
   
}

// Disable 'Powered by Drupal block
function _newprofile_profile_config_blocks() {
    db_query("UPDATE blocks SET status=0 WHERE theme='openvce' and region='footer'");
}

// Create forum topic.
function _newprofile_profile_set_term() {
  $vid_forum = db_result(db_query("SELECT vid FROM vocabulary_node_types  WHERE TYPE = '%s'", "forum"));
  // Define the terms of the topic vocabulary.
  $terms_topic = array(
    array(
      'name' => 'General Discussion',
      'vid' => $vid_forum,
      'weight' => 0,
      'parent' => 0,
    ),
  );
  // Save the terms of the Topic vocabulary.
  foreach ($terms_topic as $term) {
    taxonomy_save_term($term);
  }
}